# -*- coding: utf-8 -*-

CLI_CLIENT_VERSION = '3.0.18'

CLI_BUCKET = 'ph-platform'
CLI_VERSION = "2020-11-11"

ASSUME_ROLE_ARN = 'YXJuOmF3cy1jbjppYW06OjQ0NDYwMzgwMzkwNDpyb2xlL1BoLUNsaQ=='
ASSUME_ROLE_EXTERNAL_ID = 'Ph-Cli'
