# -*- coding: utf-8 -*-
"""alfredyang@pharbers.com.

This module document the YAML Job Args for Pharbers jobs
"""


class PhYAMLJobArgs(object):
    def __init__(self, dt):
        self.key = ""
        self.value = ""
        self.dict2obj(dt)

    def dict2obj(self, dt):
        self.__dict__.update(dt)

    def __str__(self):
        return str(self.__dict__)
