def mapping():
    return [
        {
            "col_name": "UPDATE_LABEL",
            "col_desc": "第几年更新的版本",
            "candidate": [],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "COMPANY",
            "col_desc": "数据公司",
            "candidate": [],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SOURCE",
            "col_desc": "数据来源",
            "candidate": [],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "TAG",
            "col_desc": "文件标识",
            "candidate": ['_TAG'],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "PHA_ID",
            "col_desc": "PHA ID",
            "candidate": ["5#新版ID"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "PHA_HOSP_NAME",
            "col_desc": "医院名称",
            "candidate": ["6#新版名称"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "REGION",
            "col_desc": "地区",
            "candidate": ["12#Region", "9#Region"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "PROVINCE",
            "col_desc": "省份名",
            "candidate": ["14#Province", "11#Province"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "CITY",
            "col_desc": "城市名",
            "candidate": ["15#City", "12#City"],
            "type": "String",
            "not_null": True,
            "msg_type": 'err',
        },
        {
            "col_name": "CITY_TIER",
            "col_desc": "城市等级",
            "candidate": ["28#City Tier 2010", "28#City_Tier_2010"],
            "type": "String",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "DISTRICT",
            "col_desc": "区/县",
            "candidate": ["16#District"],
            "type": "String",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "LOCATION",
            "col_desc": "坐标",
            "candidate": ["13#location"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AREA_STRUCT",
            "col_desc": "建筑面积",
            "candidate": ["77#建筑面积"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AREA_MU",
            "col_desc": "占地面积(亩)",
            "candidate": ["75#占地面积(亩)", "75#占地面积_亩_"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AREA_SQ_M",
            "col_desc": "占地面积(m2)",
            "candidate": ["76#占地面积(m2)", "76#占地面积_m2_"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "HOSP_LEVEL",
            "col_desc": "医院级别",
            "candidate": ["8#Hosp_level"],
            "type": "String",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "HOSP_QUALITY",
            "col_desc": "性质（公立/私立）",
            "candidate": ["9#性质"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "HOSP_TYPE",
            "col_desc": "医院类型",
            "candidate": ["17#Type"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SPECIALTY_CATE",
            "col_desc": "标准化（综合/专科）1",
            "candidate": ["29#Specialty_1"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SPECIALTY_ADMIN",
            "col_desc": "标准化（综合/专科）2",
            "candidate": ["30#Specialty_2"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "RE_SPECIALTY",
            "col_desc": "标准化（综合/专科）re-specialty",
            "candidate": ["33#Re-Speialty"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SPECIALTY_DETAIL",
            "col_desc": "标准化（综合/专科）3",
            "candidate": ["34#Specialty 3", "34#Specialty_3"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "MILITARY",
            "col_desc": "是否为军队医院",
            "candidate": ["10#军队"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DOCT_BANK",
            "col_desc": "医生库医院",
            "candidate": ["11#医生库医院"],
            "type": "Boolean",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "BID_SAMPLE",
            "col_desc": "招标Sample",
            "candidate": [r"19#招标Sample\n(county HP)\n共有样本2303，县医院样本932", "19#招标Sample_(county HP)_共有样本2303，县医院样本932"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "EPILEPSY",
            "col_desc": "癫痫专科",
            "candidate": ["80#癫痫专科"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "生殖中心",
            "col_desc": "REPRODUCE",
            "candidate": ["81#生殖中心"],
            "type": "String",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DRUGINCOME_RMB",
            "col_desc": "西药收入",
            "candidate": ["35#Est_DrugIncome_RMB"],
            "type": "Double",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "EMPLOYEES_NUM",
            "col_desc": "在职员工人数",
            "candidate": ["71#在职员工人数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DOCTORS_NUM",
            "col_desc": "医生数",
            "candidate": ["36#医生数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "AUTH_BED_NUM",
            "col_desc": "编制床位数",
            "candidate": ["73#编制床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OPEN_BED_NUM",
            "col_desc": "开放床位数",
            "candidate": ["74#开放床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "BED_NUM",
            "col_desc": "床位数",
            "candidate": ["37#床位数"],
            "type": "Integer",
            "not_null": True,
            "msg_type": 'warning',
        },
        {
            "col_name": "GENERAL_BED_NUM",
            "col_desc": "全科床位数",
            "candidate": ["39#全科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "INTERNAL_BED_NUM",
            "col_desc": "内科床位数",
            "candidate": ["40#内科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SURG_BED_NUM",
            "col_desc": "外科床位数",
            "candidate": ["41#外科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OPHTH_BED_NUM",
            "col_desc": "眼科床位数",
            "candidate": ["42#眼科床位数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "ANNU_DIAG_TIME",
            "col_desc": "年诊疗人次",
            "candidate": ["43#年诊疗人次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_DIAG_TIME",
            "col_desc": "门诊诊次",
            "candidate": ["44#门诊诊次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "INTERNAL_DIAG_TIME",
            "col_desc": "内科诊次",
            "candidate": ["45#内科诊次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SURG_DIAG_TIME",
            "col_desc": "外科诊次",
            "candidate": ["46#外科诊次"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "ADMIS_TIME",
            "col_desc": "入院人数",
            "candidate": ["47#入院人数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "SURG_TIME",
            "col_desc": "住院病人手术人次数",
            "candidate": ["48#住院病人手术人次数"],
            "type": "Integer",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "MED_INCOME",
            "col_desc": "医疗收入",
            "candidate": ["49#医疗收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_INCOME",
            "col_desc": "门诊收入",
            "candidate": ["50#门诊收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_TREAT_INCOME",
            "col_desc": "门诊治疗收入",
            "candidate": ["51#门诊治疗收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_SURG_INCOME",
            "col_desc": "门诊手术收入",
            "candidate": ["52#门诊手术收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_INCOME",
            "col_desc": "住院收入",
            "candidate": ["53#住院收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "BED_INCOME",
            "col_desc": "住院床位收入",
            "candidate": ["54#住院床位收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_TREAT_INCOME",
            "col_desc": "住院治疗收入",
            "candidate": ["55#住院治疗收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_SURG_INCOME",
            "col_desc": "住院手术收入",
            "candidate": ["56#住院手术收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "DRUG_INCOME",
            "col_desc": "药品收入",
            "candidate": ["57#药品收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_DRUG_INCOME",
            "col_desc": "门诊药品收入",
            "candidate": ["58#门诊药品收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "OUTP_WST_DRUG_INCOME",
            "col_desc": "门诊西药收入",
            "candidate": ["59#门诊西药收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_DRUG_INCOME",
            "col_desc": "住院药品收入",
            "candidate": ["60#住院药品收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "IN_HOSP_WST_DRUG_INCOME",
            "col_desc": "住院西药收入",
            "candidate": ["61#住院西药收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
        {
            "col_name": "COUNTY_HOSP_WST_DRUG_INCOME",
            "col_desc": "2017年县医院西药收入",
            "candidate": ["62#2017年县医院西药收入"],
            "type": "Double",
            "not_null": False,
            "msg_type": '',
        },
    ]
